.slicer-box[data-v-9beda1fc]{margin-right:.8rem;min-width:10rem;max-width:20rem}.slicer-box .cp-select[data-v-9beda1fc]{width:100%}.pybi-tabs[data-v-365c9973]{width:100%;display:flex}.pybi-input[data-v-3247582b]{min-width:18em}.pybi-box[data-v-a6587c10]{position:relative;width:100%;display:flex;flex-direction:column;align-items:var(--75d7665f);justify-content:var(--17c2b856);overflow:auto;gap:.8em}.pybi-box .item-box[data-v-a6587c10]{width:100%;overflow:visible;display:flex}.pybi-flow-box[data-v-de89203e]{display:flex;flex-direction:row;flex-wrap:wrap;align-items:center;justify-content:var(--57ed0846);width:100%}.pybi-flow-box[data-v-de89203e]>.pybi-space[data-auto-grow]{flex-grow:9999}.pybi-flow-box[data-v-de89203e]>*[data-pybi-auto-width]{width:unset}.grid-box[data-v-c795c342]{display:grid;grid-template-areas:var(--5f386d28);grid-template-columns:var(--9f82b32e);grid-template-rows:var(--7e13decd);gap:.8rem;justify-items:var(--21ef3978);align-items:var(--64b0babb);width:100%}.grid-box>.item[data-v-c795c342]{display:flex}.grid-box>.item[data-v-c795c342]>p{overflow:hidden;overflow-wrap:break-word}.grid-box[data-v-c795c342]>*{overflow-x:auto;width:100%}.textValue-box[data-v-63313f93]{display:inline-block;white-space:pre-wrap;margin:0;box-sizing:initial}.md-box[data-v-1bf08f37]{width:100%;height:var(--4fd07687)}.md-box[data-v-1bf08f37][data-v-1bf08f37] h1{display:block;font-size:2em;margin-block-start:.67em;margin-block-end:.67em;margin-inline-start:0px;margin-inline-end:0px;font-weight:700;line-height:normal;letter-spacing:normal}.md-box[data-v-1bf08f37][data-v-1bf08f37] h2{display:block;font-size:1.5em;margin-block-start:.83em;margin-block-end:.83em;margin-inline-start:0px;margin-inline-end:0px;font-weight:700;line-height:normal;letter-spacing:normal}.md-box[data-v-1bf08f37][data-v-1bf08f37] h3{display:block;font-size:1.17em;margin-block-start:1em;margin-block-end:1em;margin-inline-start:0px;margin-inline-end:0px;font-weight:700;line-height:normal;letter-spacing:normal}.md-box[data-v-1bf08f37][data-v-1bf08f37] h4{display:block;margin-block-start:1.33em;margin-block-end:1.33em;margin-inline-start:0px;margin-inline-end:0px;font-weight:700;line-height:normal;letter-spacing:normal}.md-box[data-v-1bf08f37][data-v-1bf08f37] h5{display:block;font-size:.83em;margin-block-start:1.67em;margin-block-end:1.67em;margin-inline-start:0px;margin-inline-end:0px;font-weight:700;line-height:normal;letter-spacing:normal}.pybi-space[data-v-baf5cd60]{width:var(--38253cf2);height:var(--38253cf2);visibility:collapse}.pybi-foreach[data-v-d293d89e]{position:relative}.pybi-checkbox[data-v-2f3725fd]{display:flex;flex-direction:column;flex-wrap:nowrap;width:100%;position:relative}.pybi-checkbox svg[data-v-2f3725fd]{width:1em;height:1em}.pybi-checkbox>header[data-v-2f3725fd]{background-color:#adcff3;border-radius:5px;height:25px;width:100%;flex-shrink:0;display:flex;justify-content:space-between;align-items:center}.pybi-checkbox>header .title[data-v-2f3725fd]{font-size:1.1em;padding:.1em .3em}.pybi-checkbox>header .funs-buttons[data-v-2f3725fd]{display:flex;flex-direction:row}.pybi-checkbox>header .funs-buttons .funs-icon[data-v-2f3725fd]{border-radius:50%;display:flex;justify-content:center;align-items:center;padding:.3em;-webkit-user-select:none;user-select:none;transition:.3s;cursor:pointer}.pybi-checkbox>header .funs-buttons .funs-icon[data-v-2f3725fd]:hover{box-shadow:0 4px 6px #0000001a}.pybi-checkbox .list-mode[data-v-2f3725fd]{overflow:auto}.pybi-checkbox .list-mode .labels-box[data-v-2f3725fd]{display:flex;flex-wrap:nowrap;flex-direction:column;gap:.5em}.pybi-checkbox .list-mode .labels-box .pybi-checkbox_content[data-v-2f3725fd]{display:flex;gap:.3em;justify-content:flex-start;align-items:center;-webkit-user-select:none;user-select:none;height:1.5em}.pybi-checkbox .tile-mode[data-v-2f3725fd]{--label-main-color: rgba(203, 222, 242, .9);overflow:auto}.pybi-checkbox .tile-mode .labels-box[data-v-2f3725fd]{display:flex;flex-wrap:wrap;flex-direction:var(--6c5c2c06);gap:.2em;padding:.3em .1em .3em 0}.pybi-checkbox .tile-mode .labels-box .pybi-checkbox_content[data-v-2f3725fd]{border:1px solid var(--label-main-color);border-radius:15px;height:3em;padding:1em;display:flex;gap:.3em;justify-content:center;align-items:center;-webkit-user-select:none;user-select:none;cursor:pointer;height:1.5em;transition:.3s}.pybi-checkbox .tile-mode .labels-box .pybi-checkbox_content[data-v-2f3725fd]:hover{text-decoration:underline}.pybi-checkbox .tile-mode .labels-box .pybi-checkbox_content-checked[data-v-2f3725fd]{background-color:var(--label-main-color)}.err[data-v-938c3bc4]{width:100%;color:red;border:2px dashed #ba4949;padding:.8rem}.err>p[data-v-938c3bc4]:first-child{font-size:1.2rem;margin:.2rem 0}
